/*----------------------------------------------------------------------------
 *      Name:    MEMORY.C
 *      Purpose: USB Mass Storage Demo
 *      Version: V1.10
 *----------------------------------------------------------------------------
 *      This software is supplied "AS IS" without any warranties, express,
 *      implied or statutory, including but not limited to the implied
 *      warranties of fitness for purpose, satisfactory quality and
 *      noninfringement. Keil extends you a royalty-free right to reproduce
 *      and distribute executable files created using this software for use
 *      on Philips LPC microcontroller devices only. Nothing else gives you
 *      the right to use this software.
 *
 *      Copyright (c) 2005-2006 Keil Software.
 *---------------------------------------------------------------------------*/
#include <lpc288x.h>                        /* LPC214x definitions */

#include "type.h"
#include "irq.h"
#include "target.h"

#include "usb.h"
#include "usbcfg.h"
#include "usbhw.h"
#include "usbcore.h"
#include "mscuser.h"
#include "memory.h"

extern BYTE Memory[MSC_MemorySize];         /* MSC Memory in RAM */


/* Main Program */

int main (void) {
  DWORD n, DisconnectFlag = 0;

  TargetResetInit();

  for (n = 0; n < MSC_ImageSize; n++) {     /* Copy Initial Disk Image */
    Memory[n] = DiskImage[n];               /*   from Flash to RAM     */
  }	
    
  if ( install_IRQ(26, 1, USB_ISR ) == FALSE )
  {
	while ( 1 );			/* Fatal error due to ISR installation failure */	
  }
  INT_REQ26=(1<<28)|(1<<27)|(1<<26)|(1<<16)|0x1; 
  INT_VECTOR0=IRQ_TABLE_BASE & MASK_INDEX;

   /* Check VBUS signal, make it input */
  MODE1_7 &= ~(1<<0);
  MODE0_7 &= ~(1<<0);

  while ( 1 )
  {
	if ( PINS_7 & (0x1<<0) && !DisconnectFlag )
	{
	  USB_Init();				/* USB Initialization */
	  USB_Connect(TRUE);		/* USB Connect */
	  if ( !(PINS_7 & (0x1<<0)) )
	  {
		/* Disconnected, reset flag */
		DisconnectFlag = 0;
		USB_Connect(FALSE);	
	  }
	  else	 
	  {
		/* Still connected, set flag, no need to go to Init() and 
		Connect() again */
		DisconnectFlag = 1;
	  }
	}
  }
}
